@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Module::Faker::Heavy;
+package Module::Faker::Heavy 0.023;
 # ABSTRACT: where the fake sausage gets made
-$Module::Faker::Heavy::VERSION = '0.017';
+
 use Carp ();
 use Text::Template;
 
@@ -56,11 +56,23 @@ Module::Faker::Heavy - where the fake sausage gets made
 
 =head1 VERSION
 
-version 0.017
+version 0.023
+
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
